@@ -66,7 +66,7 @@ randomize_raster <- function(raster,
 
       habitat_id <- as.numeric(names(habitats[current_habitat])) # get value of current habitat
 
-      random_cell <- sample(which(random_matrix == -999), size = 1) # random cell which is still -999
+      random_cell <- shar::rcpp_sample(x = which(random_matrix == -999), n = 1) # random cell which is still -999
 
       random_matrix[random_cell] <- habitat_id # assign habitat to cell
 
@@ -98,7 +98,7 @@ randomize_raster <- function(raster,
           if(length(empty_neighbours) > 0){
 
             # sample random neighbour
-            random_neighbour <- sample(empty_neighbours, size = 1)
+            random_neighbour <- shar::rcpp_sample(x = empty_neighbours, n = 1)
 
             # get matrix index of sampled neighbour
             random_neighbour <- matrix(neighbours[random_neighbour, ], ncol = 2)
@@ -113,7 +113,7 @@ randomize_raster <- function(raster,
           else{
 
             # random cell which is still -999
-            random_cell <- sample(which(random_matrix == -999), size = 1)
+            random_cell <- shar::rcpp_sample(x = which(random_matrix == -999), n = 1)
 
             # assign habitat to cell
             random_matrix[random_cell] <- habitat_id
@@ -126,7 +126,7 @@ randomize_raster <- function(raster,
         else {
 
           # random cell which is still -999
-          random_cell <- sample(which(random_matrix == -999), size = 1)
+          random_cell <- shar::rcpp_sample(x = which(random_matrix == -999), n = 1)
 
           # assign habitat to cell
           random_matrix[random_cell] <- habitat_id
@@ -160,7 +160,7 @@ randomize_raster <- function(raster,
   # add input pattern to randomizations
   if(return_input){
 
-    if(simplify){
+    if(simplify && verbose){
       message("\n")
       warning("'simplify = TRUE' not possible for 'return_input = TRUE'.", call. = FALSE)
     }
@@ -174,7 +174,7 @@ randomize_raster <- function(raster,
 
     if(simplify) {
 
-      if(n_random > 1) {
+      if(n_random > 1 && verbose) {
         message("\n")
         warning("'simplify = TRUE' not possible for 'n_random > 1'.", call. = FALSE)
       }
