@@ -20,10 +20,12 @@ marks_recon <- shar::reconstruct_marks(pattern = pattern_random_marks,
 testthat::test_that("plot_randomized_pattern returns plot", {
 
   shar::plot_randomized_pattern(pattern_random_a,
-                                verbose = FALSE)
+                                verbose = FALSE,
+                                ask = FALSE)
 
   shar::plot_randomized_pattern(pattern_random_a, what = "pp",
-                                verbose = FALSE)
+                                verbose = FALSE,
+                                ask = FALSE)
 })
 
 testthat::test_that("plot_randomized_pattern returns error if input is named wrong", {
@@ -52,7 +54,7 @@ testthat::test_that("plot_randomized_patterns returns error if method is wrong",
   testthat::expect_error(shar::plot_randomized_pattern(marks_recon,
                                                        method = "wrong",
                                                        verbose = FALSE),
-                         regexp = "'method' must be either 'method = 'spatial'' or 'method = 'marks''")
+                         regexp = "'method' must be either 'method = 'spatial' or 'method = 'marks'.")
   })
 
 testthat::test_that("plot_randomized_patterns returns error if what is wrong", {
