@@ -45,7 +45,7 @@ testthat::test_that("Argument comp_fast = TRUE is working", {
   pattern_recon <- shar::reconstruct_pattern(pattern = shar::species_a,
                                              n_random = 1,
                                              max_runs = 1,
-                                             comp_fast = 50,
+                                             comp_fast = 0,
                                              verbose = FALSE)
 
   testthat::expect_type(pattern_recon, type = "list")
@@ -53,6 +53,19 @@ testthat::test_that("Argument comp_fast = TRUE is working", {
   testthat::expect_length(pattern_recon, n = 2)
 })
 
+testthat::test_that("Reconstruction stops if e_threshold is reached", {
+
+  pattern_recon <- shar::reconstruct_pattern(pattern = shar::species_b,
+                                             e_threshold = 0.5,
+                                             n_random = 19,
+                                             verbose = FALSE)
+
+  energy <- shar::calculate_energy(pattern_recon, verbose = FALSE)
+
+  testthat::expect_true(object = all(energy < 0.5))
+})
+
+
 testthat::test_that("simplify works for reconstruct_pattern", {
 
   pattern_recon <- shar::reconstruct_pattern(pattern = shar::species_a,
@@ -79,14 +92,12 @@ testthat::test_that("reconstruct_pattern returns warnings", {
                                                      n_random = 2,
                                                      max_runs = 1,
                                                      return_input = FALSE,
-                                                     simplify = TRUE,
-                                                     verbose = FALSE),
+                                                     simplify = TRUE),
                            regexp = "'simplify = TRUE' not possible for 'n_random > 1'.")
 
   testthat::expect_warning(shar::reconstruct_pattern(pattern = shar::species_a,
                                                      n_random = 1,
                                                      max_runs = 1,
-                                                     simplify = TRUE,
-                                                     verbose = FALSE),
+                                                     simplify = TRUE),
                            regexp = "'simplify = TRUE' not possible for 'return_input = TRUE'.")
 })
